Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Delegate ¶
A Delegate represents an external delegate that the protocolhandler can notify about data being processed.
type Handler ¶
type Handler interface {
NeedsTLS() bool
SetDelegate(delegate Delegate)
Accept()
ReceiveData(data []byte)
Execute(name string, args []string)
Upload(source string, destination string)
Download(source string, destination string)
Close()
}
A Handler represents a type capable of handling and decoding C2 traffic.
Click to show internal directories.
Click to hide internal directories.